@@ -6,12 +6,13 @@ import json
 import logging
 from pathlib import Path
 
+from rpi_camera_colony.config.config import get_interface_mac_address
 from rpi_camera_colony.config.config import get_local_ip_address
-from rpi_camera_colony.tools.comms import ListenerStream
-from rpi_camera_colony.tools.comms import SocketCommunication
-from rpi_camera_colony.tools.files import DummyFileObject
-from rpi_camera_colony.tools.files import get_datestr
-from rpi_camera_colony.tools.files import make_recording_file_names
+from rpi_camera_colony.files import DummyFileObject
+from rpi_camera_colony.files import get_datestr
+from rpi_camera_colony.files import make_recording_file_names
+from rpi_camera_colony.network_communication import ListenerStream
+from rpi_camera_colony.network_communication import SocketCommunication
 
 try:
     from rpi_camera_colony.acquisition.camera import Camera
@@ -61,7 +62,9 @@ class PiAcquisitionControl(object):
         self.acquisition_group = acquisition_group or self.acquisition_group
         self.acquisition_name = acquisition_name or self.acquisition_name
         self.control_stream_ip = control_stream_ip or self.control_stream_ip
-        self.control_stream_port = control_stream_port or self.control_stream_port
+        self.control_stream_port = (
+            control_stream_port or self.control_stream_port
+        )
 
         for attr, value in kwargs.items():
             if hasattr(self, attr):
@@ -114,6 +117,7 @@ class PiAcquisitionControl(object):
             and not isinstance(v, ListenerStream)
             and not isinstance(v, type(self.camera))
         }
+        metadata["mac_address"] = get_interface_mac_address()
 
         save_path = self.acquisition_files["metadata"]
         with open(save_path, "w") as f:
@@ -140,14 +144,17 @@ class PiAcquisitionControl(object):
         self.acquisition_files = make_recording_file_names(
             path=self.acquisition_file_base,
         )
-        logging.info(f"{self.instance_name} - files: {self.acquisition_files}")
+        logging.debug(
+            f"Files:\n{json.dumps(self.acquisition_files, sort_keys=True, indent=4)}"
+        )
 
     def _received_command(self, command):
         command = [c.decode() for c in command]
         recipient, message_dict_str = command
         message = json.loads(message_dict_str, encoding="utf-8")
 
-        logging.info(f"Recipient '{recipient}' reporting message '{message}'")
+        ms = message.get("status", "")
+        logging.info(f"Received: {message['type']} {'>' if ms else ''} {ms}")
 
         if message["type"] == "command":
             self._update_camera_status(new_status=message["status"])
@@ -161,12 +168,16 @@ class PiAcquisitionControl(object):
             # Camera config_data
             if hasattr(self.camera, setting_name):
                 setattr(self.camera, setting_name, setting_value)
-                logging.debug(f"setattr(self.camera, {setting_name}, {setting_value})")
+                logging.debug(
+                    f"setattr(self.camera, {setting_name}, {setting_value})"
+                )
 
             # PiAcquisitionControl config_data
             if hasattr(self, setting_name):
                 setattr(self, setting_name, setting_value)
-                logging.debug(f"setattr(self, {setting_name}, {setting_value})")
+                logging.debug(
+                    f"setattr(self, {setting_name}, {setting_value})"
+                )
 
     def _update_camera_status(self, new_status="stop"):
         logging.debug(f"New status: {new_status} on {self.instance_name}")
