@@ -7,36 +7,55 @@ import logging
 import time
 from pathlib import Path
 
-import zmq
-
-from rpi_camera_colony.acquisition.remote_control import RemoteAcquisitionControl
+from rpi_camera_colony.acquisition.remote_control import (
+    RemoteAcquisitionControl,
+)
 from rpi_camera_colony.config.config import load_config
-from rpi_camera_colony.tools.comms import find_available_port
-from rpi_camera_colony.tools.comms import ListenerStream
-from rpi_camera_colony.tools.comms import SocketCommunication
-from rpi_camera_colony.tools.files import close_file_safe
-from rpi_camera_colony.tools.files import get_datestr
+from rpi_camera_colony.files import close_file_safe
+from rpi_camera_colony.files import get_datestr
+from rpi_camera_colony.log import log_level_name_to_value
+from rpi_camera_colony.network_communication import find_available_port
+from rpi_camera_colony.network_communication import ListenerStream
+from rpi_camera_colony.network_communication import SocketCommunication
 
 
 def parse_args_for_conductor():
     parser = argparse.ArgumentParser(
-        description="Input arguments",
+        description="RPi Camera Colony: Conductor",
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
     )
     parser.add_argument(
         "--config-file",
         "-c",
         type=str,
-        default=Path(__file__).parent.parent / "config/example.config",
+        default="",
         help="Settings file",
     )
     parser.add_argument(
         "--acquisition-name",
         "-n",
         type=str,
-        default="default_acq_name_parser__" + get_datestr(),
+        default="_test_rcc_conductor_parser__" + get_datestr(),
         help="Acquisition name [only name; path on Conductor should be defined in config]",
     )
+    parser.add_argument(
+        "--calibration",
+        default=False,
+        action="store_true",
+    )
+    parser.add_argument(
+        "--max-acquisition-time",
+        "-t",
+        default=2 * 3600,
+        type=int,
+        help="Maximum recording time, seconds.",
+    )
+    parser.add_argument(
+        "--debug",
+        "-d",
+        default=False,
+        action="store_true",
+    )
     return parser.parse_args()
 
 
@@ -55,6 +74,11 @@ class Conductor(object):
     auto_init = False
     auto_init_remote = True
 
+    run_for_calibration = False
+    calibration_framerate = 2
+
+    debug = False
+
     _logging_socket = None
     _logging_stream_callback = None
     _log_level = "INFO"
@@ -71,6 +95,7 @@ class Conductor(object):
         self,
         config_file=None,
         acquisition_group="",
+        acquisition_group_divider="__",
         acquisition_name=None,
         acquisition_time=None,
         logging_stream_callback=None,
@@ -78,6 +103,9 @@ class Conductor(object):
         auto_init_remote=True,
         delay_for_networking=4,
         delay_for_remote_instance=6,
+        run_for_calibration=False,
+        debug=False,
+        **kwargs,
     ):
         """Create new Acquisition Conductor."""
         super(Conductor, self).__init__()
@@ -85,7 +113,10 @@ class Conductor(object):
         self.config_file = config_file
         self._load_config()
 
-        self._log_level = self.config_data["log"]["level"]
+        self.debug = debug
+        self._log_level = (
+            "DEBUG" if self.debug else self.config_data["log"]["level"]
+        )
         logger = logging.getLogger()
         logger.setLevel(getattr(logging, self._log_level))
 
@@ -97,6 +128,7 @@ class Conductor(object):
         )
         self.auto_init = auto_init
         self.auto_init_remote = auto_init_remote
+        self.run_for_calibration = run_for_calibration
 
         # Process arguments
         if not self.acquisition_name:
@@ -104,17 +136,23 @@ class Conductor(object):
                 "acquisition_name", "default_acq_name_get"
             )
 
-        acq_name_parts = self.acquisition_name.split("__")
-        if not self.acquisition_group:
+        # Add acquisition group if name has group segment, when split by standard divider
+        acq_name_parts = self.acquisition_name.split(acquisition_group_divider)
+        if not self.acquisition_group and len(acq_name_parts) > 1:
             self.acquisition_group = acq_name_parts[0]
 
         self.acquisition_time = (
             acq_name_parts[1] if len(acq_name_parts) > 1 else get_datestr()
         )
 
-        self.config_data["general"]["acquisition_group"] = self.acquisition_group
+        self.config_data["general"][
+            "acquisition_group"
+        ] = self.acquisition_group
         self.config_data["general"]["acquisition_name"] = self.acquisition_name
         self.config_data["general"]["acquisition_time"] = self.acquisition_time
+        self.config_data["general"][
+            "run_for_calibration"
+        ] = self.run_for_calibration
 
         for c in self.config_data["controllers"].keys():
             self.config_data["controllers"][c][
@@ -124,16 +162,23 @@ class Conductor(object):
                 "acquisition_group"
             ] = self.acquisition_group
 
+            if self.run_for_calibration:
+                self.config_data["controllers"][c][
+                    "framerate"
+                ] = self.calibration_framerate
+
         self._log_to_file = self.config_data["log"].get("log_to_file")
         self._log_to_console = self.config_data["log"].get("log_to_console")
 
         # Execute main components
         self._open_network_comms()
-        logging.debug(f"Waiting {delay_for_networking}s for networking to come up..")
+        logging.info(
+            f"Waiting {delay_for_networking}s for networking to come up.."
+        )
         time.sleep(delay_for_networking)
 
         self._make_acquisition_controllers(auto_init=auto_init_remote)
-        logging.debug(
+        logging.info(
             f"Waiting {delay_for_remote_instance}s for remote instance to listen.."
         )
         time.sleep(delay_for_remote_instance)
@@ -163,7 +208,10 @@ class Conductor(object):
             start_port=start_port, ip_address=address
         )
 
-        assert available_port_logging is not None and available_port_control is not None
+        assert (
+            available_port_logging is not None
+            and available_port_control is not None
+        )
         self.config_data["log"]["port"] = available_port_logging
         self.config_data["control"]["port"] = available_port_control
 
@@ -199,13 +247,28 @@ class Conductor(object):
             )
             self._log_file = open(log_file, "w")
             self._write_to_log(f"# Log for: {self.acquisition_name}\n")
-            logging.debug(f"Logging  remote messages to {self._log_file}")
+            logging.info(f"Logging remote messages to: {self._log_file.name}")
 
     def _callback_receiver(self, message=None):
         topic, message = [m.decode() for m in message]
-        out_string = f"REMOTE: {topic} :: {message}".strip("\n")
+        instance_name, log_level_on_remote = topic.split(".")
 
-        if self._log_to_console and self._log_level.upper() in topic.upper():
+        try:  # FIXME: Why is ARM logger not formatted correctly ? Missing timestamps and dash separators.
+            (
+                remote_dt,
+                remote_level,
+                remote_position,
+                remote_message,
+            ) = message.split(" - ")
+            out_string = f"REMOTE: {instance_name} - {remote_position} - {remote_message}".strip(
+                "\n"
+            )
+        except BaseException:
+            out_string = message
+
+        message_level = log_level_name_to_value(name=log_level_on_remote)
+        target_level = log_level_name_to_value(name=self._log_level)
+        if self._log_to_console and message_level >= target_level:
             logging.info(out_string)
 
         if (
@@ -223,7 +286,9 @@ class Conductor(object):
     def _make_acquisition_controllers(self, auto_init=True):
         """Make local objects to handle interaction with remote acquisition controller."""
         for instance_name, _ in self.config_data["controllers"].items():
-            self._acquisition_controllers[instance_name] = RemoteAcquisitionControl(
+            self._acquisition_controllers[
+                instance_name
+            ] = RemoteAcquisitionControl(
                 instance_name=instance_name,
                 config_data=self.config_data,
                 control_socket_wrapper=self._control_socket,
@@ -237,6 +302,13 @@ class Conductor(object):
 
     def start_acquisition(self):
         """Start acquisition."""
+        for _, acq in self._acquisition_controllers.items():
+            acq.transmit_settings()
+
+        time.sleep(
+            1
+        )  # Essential delay to give remote time to process settings
+
         for _, acq in self._acquisition_controllers.items():
             acq.start_acquisition()
 
@@ -286,3 +358,5 @@ class Conductor(object):
 
         self.__cleaned_up = True
         self.active = False
+
+        logging.info("Exiting RCC Conductor.")
