@@ -9,13 +9,15 @@ from tqdm import tqdm
 
 from rpi_camera_colony.control.conductor import Conductor
 from rpi_camera_colony.control.conductor import parse_args_for_conductor
+from rpi_camera_colony.log import setup_logging_control
 
 
 def main():
     args = parse_args_for_conductor()
+    setup_logging_control()
 
     progress = tqdm(
-        total=7200,
+        total=args.max_acquisition_time,
         desc="Recording progress",
         unit="seconds",
         bar_format="{desc}: {percentage:3.0f}%| | {n:.2f}/{total_fmt} [{elapsed}<{remaining}, {rate_fmt}{postfix}]",
